%global major 1
%define libname %mklibname nvidia-egl-wayland %major
%define devname %mklibname nvidia-egl-wayland -d

%global commit0 0c6f823808fb03f92672d80b97e83819ba95c041
%global date 20241210
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global tag %{version}

Name:           egl-wayland
Version:        1.1.17
Release:        %mkrel 1
Group:          System/Libraries
Summary:        Wayland EGL External Platform library
License:        MIT
URL:            https://github.com/NVIDIA/%{name}

%if 0%{?tag:1}
Source0:        %url/archive/%{version}/%{name}-%{version}.tar.gz
%else
Source0:        %url/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
%endif

BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  libtool
BuildRequires:  pkgconfig(egl) >= 1.5
BuildRequires:  pkgconfig(eglexternalplatform) >= 1.1
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl-backend) >= 3
# Explicit synchronization since 1.34:
BuildRequires:  pkgconfig(wayland-protocols) >= 1.34
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)

# Required for directory ownership
Requires:       libglvnd-egl%{?_isa}

%description
EGL External Platform library to add client-side Wayland support to EGL on top
of EGLDevice and EGLStream families of extensions.

This library implements an EGL External Platform interface to work along with
EGL drivers that support the external platform mechanism.

%package json
Summary: JSON data files for Wayland EGL External Platform library
Group: System/Libraries
BuildArch: noarch
Conflicts: %{_lib}nvidia-egl-wayland1 < 1.0.3-2

%description json
JSON data files for Wayland EGL External Platform library.

%package -n %libname
Summary: Wayland EGL External Platform library
Group: System/Libraries
Requires: %{name}-json >= %{version}-%{release}
Conflicts: x11-driver-video-nvidia-current < 450.66-4

%description -n %libname
EGL External Platform library to add client-side Wayland support to EGL on top
of EGLDevice and EGLStream families of extensions.

This library implements an EGL External Platform interface to work along with
EGL drivers that support the external platform mechanism.

%package -n %devname
Group:          Development/C
Summary:        Wayland EGL External Platform library development package
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %devname
Development files and headers for Wayland EGL External Platform library.

%prep
%if 0%{?tag:1}
%autosetup -p1
%else
%autosetup -p1 -n %{name}-%{commit0}
%endif

%build
%meson
%meson_build

%install
%meson_install

%files -n %libname
%doc README.md
%license COPYING
%{_libdir}/libnvidia-egl-wayland.so.%{major}{,.*}

%files json
%{_datadir}/egl/egl_external_platform.d/10_nvidia_wayland.json

%files -n %devname
%{_libdir}/libnvidia-egl-wayland.so
%{_libdir}/pkgconfig/wayland-eglstream.pc
%{_datadir}/pkgconfig/wayland-eglstream-protocols.pc
%{_datadir}/wayland-eglstream/


%changelog
* Tue Dec 17 2024 daviddavid <daviddavid> 1.1.17-1.mga10
+ Revision: 2125740
- new version: 1.1.17

* Mon Nov 13 2023 tv <tv> 1.1.13-1.mga10
+ Revision: 2006549
- Update to 1.1.13

* Thu Sep 21 2023 tv <tv> 1.1.12-1.mga10
+ Revision: 1989084
- Update to 1.1.12
- Fix destroying objects *before* their queues (rhbz#2223856)

* Sat Nov 05 2022 tv <tv> 1.1.11-1.mga9
+ Revision: 1903799
- Update to 1.1.11

* Thu Jun 30 2022 tv <tv> 1.1.10-2.mga9
+ Revision: 1866812
- Update to latest snapshot
- Fix GTK4 resizing

* Wed Jun 22 2022 tv <tv> 1.1.10-1.mga9
+ Revision: 1865409
- Update to 1.1.10

* Wed Mar 30 2022 umeabot <umeabot> 1.1.9-3.mga9
+ Revision: 1834274
- Mageia 9 Mass Rebuild

* Wed Nov 24 2021 tv <tv> 1.1.9-2.mga9
+ Revision: 1759082
- Add upstream fixes

* Sat Oct 30 2021 tv <tv> 1.1.9-1.mga9
+ Revision: 1753339
- Need a newer libglvnd
- Update to 1.1.9
- Add 15_nvidia_gbm.json
- Update to 1.1.8

* Sun Jun 13 2021 tv <tv> 1.1.7-1.mga9
+ Revision: 1730553
- Update to 1.1.7

* Thu May 13 2021 tv <tv> 1.1.5-4.mga9
+ Revision: 1722657
- Fix EGL stream closing causing a crash in Xwayland with EGLstream
  (rhbz#1943936, rhbz#1949415)

* Mon Sep 28 2020 ghibo <ghibo> 1.1.5-3.mga8
+ Revision: 1631000
- Add conflicts for older x11-driver-video-nvidia-current

* Sun Aug 16 2020 tv <tv> 1.1.5-2.mga8
+ Revision: 1614315
- Fix a lock related crash (rhbz#1842473)

* Tue Jun 02 2020 tv <tv> 1.1.5-1.mga8
+ Revision: 1589729
- 1.1.5

* Tue Feb 18 2020 umeabot <umeabot> 1.1.4-3.mga8
+ Revision: 1540914
- Mageia 8 Mass Rebuild

* Tue Dec 17 2019 tv <tv> 1.1.4-2.mga8
+ Revision: 1468553
- Add patch to add missing mesa includes

* Fri Oct 04 2019 tv <tv> 1.1.4-1.mga8
+ Revision: 1449172
- new release

* Tue Jul 23 2019 tv <tv> 1.1.3-1.mga8
+ Revision: 1423614
- new release

* Wed Apr 17 2019 umeabot <umeabot> 1.0.3-4.mga7
+ Revision: 1392146
- Rebuild with meson 0.50.1

* Sun Sep 23 2018 umeabot <umeabot> 1.0.3-3.mga7
+ Revision: 1297579
- Mageia 7 Mass Rebuild

* Tue Jun 19 2018 wally <wally> 1.0.3-2.mga7
+ Revision: 1238075
- add upstream patch to fix meson build
- split out json data files from library
- update summaries and descriptions

* Sat May 12 2018 tv <tv> 1.0.3-1.mga7
+ Revision: 1228477
- BR pkgconfig(egl)
- imported package egl-wayland


* Fri May 11 2018 Thierry Vignaud <tv@mageia.org> 1.0.3-1.mga7
- import from FC

* Tue Feb 06 2018 Leigh Scott <leigh123linux@googlemail.com> - 1.0.3-2.20180201git6f5f7d0
- Update to latest git snapshot
- Switch to meson
- Install .so file to -devel as it's listed in wayland-eglstream.pc
- Fix directory ownership

* Wed Jan 31 2018 Jonas Ådahl <jadahl@redhat.com> - 1.0.3-1.20180111gitb283689
- Update to 1.0.3
- Add -devel package

* Thu Aug 03 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.2-0.4.20170802git1f4b1fd
- Update to latest git snapshot

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-0.3.20170628git818b613
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-0.2.20170628git818b613
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jun 28 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.2-0.1.20170628git818b613
- Update to 1.0.2 git

* Wed Mar 08 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-0.1.20170308git582fbf3
- Update to 1.0.1 git

* Tue Feb 07 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.7.20170207git05eb000
- Add license file

* Thu Feb 02 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.6.20170120git743d702
- Add requires libglvnd-egl
- Make review changes

* Wed Feb 01 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.5.20170120git743d702
- Drop devel sub-package

* Wed Feb 01 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.4.20170120git743d702
- Add 10_nvidia_wayland.json to libs sub-package

* Wed Feb 01 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.3.20170120git743d702
- Add loader directory to common sub-package
- Move libs to sub-package

* Fri Jan 20 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.2.20170120git743d702
- Add date to release

* Fri Jan 20 2017 Leigh Scott <leigh123linux@googlemail.com> - 1.0.0-0.1.git743d702
- First build

